# openstack-image-manager

[![PyPi version](https://badgen.net/pypi/v/openstack-image-manager/)](https://pypi.org/project/openstack-image-manager/)
[![PyPi license](https://badgen.net/pypi/license/openstack-image-manager/)](https://pypi.org/project/openstack-image-manager/)

Easily manage and keep up to date a large number of images on an OpenStack environment

Documentation: <https://docs.osism.tech/openstack-image-manager/>
